@@ -1,7 +1,7 @@
 package Complete;
 
-our $DATE = '2014-12-24'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2014-12-25'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 
 our $OPT_CI          = ($ENV{COMPLETE_OPT_CI}          // 1) ? 1:0;
 our $OPT_MAP_CASE    = ($ENV{COMPLETE_OPT_MAP_CASE}    // 1) ? 1:0;
-our $OPT_EXP_IM_PATH = ($ENV{COMPLETE_OPT_EXP_IM_PATH} // 1) ? 1:0;
+our $OPT_EXP_IM_PATH = ($ENV{COMPLETE_OPT_EXP_IM_PATH} // 0) ? 1:0;
 
 1;
 # ABSTRACT: Convention for Complete::* modules family and common settings
@@ -26,7 +26,7 @@ Complete - Convention for Complete::* modules family and common settings
 
 =head1 VERSION
 
-This document describes version 0.06 of Complete (from Perl distribution Complete), released on 2014-12-24.
+This document describes version 0.07 of Complete (from Perl distribution Complete), released on 2014-12-25.
 
 =head1 DESCRIPTION
 
@@ -193,7 +193,7 @@ All L<Complete::Path>-based modules (like L<Complete::Util>'s
 C<complete_file()>), L<Complete::Module>, or L<Complete::Riap> respect this
 setting.
 
-=head2 C<$Complete::OPT_EXP_IM_PATH> => bool (default: from COMPLETE_OPT_EXP_IM_PATH or 1)
+=head2 C<$Complete::OPT_EXP_IM_PATH> => bool (default: from COMPLETE_OPT_EXP_IM_PATH or 0)
 
 Whether to "expand intermediate paths". What is meant by this is something like
 zsh: when you type something like C<cd /h/u/b/myscript> it can be completed to
@@ -203,6 +203,10 @@ All L<Complete::Path>-based modules (like L<Complete::Util>'s
 C<complete_file()>), L<Complete::Module>, or L<Complete::Riap> respect this
 setting.
 
+Currently defaults to 0 because in the case of /foo/bar and /foo2/baz, when user
+type "/foo/b" bash will keep the user stuck at "/foo" because it is the shortest
+common substring. This is annoying.
+
 =head1 ENVIRONMENT
 
 =head2 COMPLETE_OPT_CI => bool
@@ -227,7 +231,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Complete>.
+Source repository is at L<https://github.com/sharyanto/perl-Complete>.
 
 =head1 BUGS
 
